@@ -17,10 +17,9 @@ uri = uri or f'sqlite:///{os.path.abspath(os.path.dirname(__file__))}/data/notec
 #engine = create_engine(uri, echo=True)
 engine = create_engine(uri)
 Base = declarative_base()
-session = scoped_session(sessionmaker(
-    autocommit=True,
-    # autoflush=True,
-    bind=engine))
+#session = scoped_session(sessionmaker(autocommit=True,autoflush=True,bind=engine))
+#session = sessionmaker(autocommit=True, autoflush=True, bind=engine)()
+session = sessionmaker(bind=engine)()
 
 
 logging.info(f'uri:{uri}')
