@@ -16,17 +16,13 @@ class AccountAccount(RedisConnect):
     def update_value(self, suffix=""):
         data = account_api.get_account().data[0]['details']
         self.put_value(self.get_key(suffix=suffix), data)
+        for detail in data:
+            print(detail)
+            create_all()
+            session.merge(OkexClientAccountBalance(**detail))
+        session.commit()
+        create_all()
         return {"success": len(data)}
 
-    @api_route('/read', description="read market tickers")
     def get_value(self, suffix=""):
         return super(AccountAccount, self).get_value(suffix=suffix)
-
-
-data = account_api.get_account().data[0]['details']
-for detail in data:
-    print(detail)
-    create_all()
-    session.merge(OkexClientAccountBalance(**detail))
-session.commit()
-create_all()
